@@ -34,9 +34,9 @@ $HAVEIM = 0;
 $HAVELJ = 0;
 ############################################################################
 
-# This is IGAL version 2.1, an online Image GALlery generator.
+# This is IGAL version 2.2, an online Image GALlery generator.
 #   Copyright (C) 2000 Eric Pop, 2003 Wolfgang Trexler
-#   This version was enhanced by Wolfgang Trexler (wt) Apr. 2003 - May 2012
+#   This version was enhanced by Wolfgang Trexler (wt) Apr. 2003 - May 2016
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -65,7 +65,7 @@ $ExifTool = eval "use Image::ExifTool; 1" ? 1 : 0;
 
 
 # some constants
-$VERSION = "2.1";
+$VERSION = "2.2";
 $Getopt::Long::ignorecase = 0;
 $itile = "tile.png";
 $slidetemplate = "slidetemplate2.html";
@@ -235,7 +235,7 @@ if ($opt_AddSubdir) {
 			push(@directories, $file);
 		}
 	}
-	if (defined(@directories)) {
+	if (@directories) {
 		@directories = sort @directories;      # sort alphabetically, by name
 	} else {
 		print "Information: Option --AddSubdir is set, but can't find any matching subdiretories!\n";
@@ -320,7 +320,7 @@ if ($opt_c or $opt_C) {
 
 # find out if the imagemagick commands exist
 $HAVEIM = (&exist("identify") and &exist("convert")) unless ($HAVEIM);
-print "\nWARNING:  The ImageMagick package (imagemagick.org) doesn't seem to be\ninstalled.  Image dimensions will not be available in the generated HTML.\nOnly JPG images are supported... falling back onto cjpeg/djpeg/pnmscale.\n\n" unless ($HAVEIM);
+print "\nWARNING:  commands identify/convert missing!\nThe ImageMagick (imagemagick.org) or GraphicsMagick package with compatibility doesn't seem to be\ninstalled.  Image dimensions will not be available in the generated HTML.\nOnly JPG images are supported... falling back onto cjpeg/djpeg/pnmscale.\n\n" unless ($HAVEIM);
 
 # find out if the libjpeg commands exist
 $HAVELJ = (&exist("cjpeg") and &exist("djpeg") &exist("pnmscale")) unless ($HAVELJ or ($njpg == 0) or $HAVEIM);
@@ -646,7 +646,7 @@ $indexfile =~ s/<!--#IGAL-OPTIONS#-->/@igal_options/g;     # set comment about i
 $indexfile =~ s/<!--#IGAL-CSS#-->/$opt_dest$csstemplate/g; # set the name (and path) of css template file
 
 # Generate the links for directories
-if ($opt_AddSubdir && defined(@directories)) {
+if ($opt_AddSubdir && @directories) {
 
 	if (! -e "$opt_d/$opt_dest.$directorylinefile") {
 		print "No $opt_dest.$directorylinefile file ... getting a copy from $LIBDIR/\n";
